@@ -1155,16 +1155,15 @@ pub fn write_python_part(
             {
                 eprintln!("📦 Including files matching \"{pattern}\"");
                 for source in glob::glob(&pyproject_dir.join(pattern).to_string_lossy())
-                    .expect("No files found for pattern")
+                    .with_context(|| format!("Invalid glob pattern: {pattern}"))?
                     .filter_map(Result::ok)
                 {
                     let target = source.strip_prefix(pyproject_dir)?.to_path_buf();
                     if source.is_dir() {
                         writer.add_directory(target)?;
                     } else {
-                        let permissions = source.metadata()?.permissions();
                         #[cfg(unix)]
-                        let mode = permissions.mode();
+                        let mode = source.metadata()?.permissions().mode();
                         #[cfg(not(unix))]
                         let mode = 0o644;
                         writer.add_file_with_permissions(target, source, mode)?;
@@ -1254,9 +1253,8 @@ pub fn add_data(writer: &mut impl ModuleWriter, data: Option<&Path>) -> Result<(
                     .build()
                 {
                     let file = file?;
-                    let permissions = file.metadata()?.permissions();
                     #[cfg(unix)]
-                    let mode = permissions.mode();
+                    let mode = file.metadata()?.permissions().mode();
                     #[cfg(not(unix))]
                     let mode = 0o644;
                     let relative = file.path().strip_prefix(data.parent().unwrap()).unwrap();
