@@ -263,24 +263,26 @@ fn rewrite_dependencies_path(
                                     .as_array_mut()
                                     .with_context(|| {
                                         format!(
-                                        "In {}, {} {} has a features value that is not an array",
-                                        manifest_path.display(),
-                                        dep_category,
-                                        dep_name
-                                    )
+                                            "In {}, {} {} has a features value that is not an array",
+                                            manifest_path.display(),
+                                            dep_category,
+                                            dep_name
+                                        )
                                     })?;
                                 existing_features.extend(features);
                             }
+                            // See https://github.com/toml-rs/toml/issues/594
+                            dep_table.remove(&dep_name);
                             dep_table[&dep_name] = workspace_dep;
                             rewritten = true;
                         } else {
                             bail!(
-                            "In {}, {} {} is marked as `workspace = true`, but it is found neither in \
-                                the workspace manifest nor in the known path dependencies",
-                            manifest_path.display(),
-                            dep_category,
-                            dep_name
-                        )
+                                "In {}, {} {} is marked as `workspace = true`, but it is found neither in \
+                                    the workspace manifest nor in the known path dependencies",
+                                manifest_path.display(),
+                                dep_category,
+                                dep_name
+                            )
                         }
                         continue;
                     }
@@ -292,13 +294,6 @@ fn rewrite_dependencies_path(
                     // Cargo.toml contains relative paths, and we're already in LOCAL_DEPENDENCIES_FOLDER
                     toml_edit::value(format!("../{dep_name}"))
                 };
-                if workspace_inherit {
-                    // Remove workspace inheritance now that we converted it into a path dependency
-                    dep_table[&dep_name]
-                        .as_table_like_mut()
-                        .unwrap()
-                        .remove("workspace");
-                }
                 rewritten = true;
             }
         }
@@ -546,21 +541,19 @@ fn find_path_deps(cargo_metadata: &Metadata) -> Result<HashMap<String, PathBuf>>
     while let Some(top) = stack.pop() {
         for dependency in &top.dependencies {
             if let Some(path) = &dependency.path {
+                let dep_name = dependency.rename.as_ref().unwrap_or(&dependency.name);
                 if matches!(dependency.kind, cargo_metadata::DependencyKind::Development) {
                     // Skip dev-only dependency
                     debug!(
                         "Skipping development only dependency {} ({})",
-                        dependency.name, path
+                        dep_name, path
                     );
                     continue;
                 }
                 // we search for the respective package by `manifest_path`, there seems
                 // to be no way to query the dependency graph given `dependency`
                 let dep_manifest_path = path.join("Cargo.toml");
-                path_deps.insert(
-                    dependency.name.clone(),
-                    PathBuf::from(dep_manifest_path.clone()),
-                );
+                path_deps.insert(dep_name.clone(), PathBuf::from(dep_manifest_path.clone()));
                 if let Some(dep_package) = cargo_metadata
                     .packages
                     .iter()
